/*============================================================================
  File:     RunawayLogFile.sql

  Summary:  This script shows how a transaction
			log can grow out of control if it
			is mis-managed

  Date:     June 2009

  SQL Server Versions:
		10.0.2531.00 (SS2008 SP1)
		9.00.4035.00 (SS2005 SP3)
------------------------------------------------------------------------------
  Written by Paul S. Randal, SQLskills.com

  For more scripts and sample code, check out 
    http://www.SQLskills.com

  You may alter this code for your own *non-commercial* purposes. You may
  republish altered code as long as you give due credit.
  
  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
  TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
  PARTICULAR PURPOSE.
============================================================================*/

USE MASTER;
GO

IF DATABASEPROPERTYEX ('DBMaint2008', 'Version') > 0
	DROP DATABASE DBMaint2008;

CREATE DATABASE DBMaint2008;
GO
USE DBMaint2008;
GO
SET NOCOUNT ON;
GO

-- Create a table that will grow very
-- quickly and generate lots of transaction
-- log
CREATE TABLE BigRows (
	c1 INT IDENTITY,
	c2 CHAR (8000) DEFAULT 'a');
GO

-- Make sure the database is in FULL
-- recovery model
ALTER DATABASE DBMaint2008 SET RECOVERY FULL;
GO

-- In another window, run LoopInserts.sql

-- Go to perfmon and monitor the log
-- Set scale for size and used size to 0.01

-- Watch the saw-tooth - even though we're in
-- FULL recovery mode, the log is being cleared
-- We're actually in pseudo-simple until a full
-- database backup is taken

BACKUP DATABASE DBMaint2008 TO
	DISK = 'C:\SQLskills\DBMaint2008.bck'
	WITH INIT, STATS;
GO

-- Now the log is out of control...
-- Change comment out the  waitfor and set the
-- counters to 0.0001

-- Log size is hundreds of MB!

-- What's causing the log to not be cleared?
SELECT [log_reuse_wait_desc]
	FROM master.sys.databases
	WHERE [name] = 'DBMaint2008';
GO

-- If running 2008 log_reuse can be misleading...
CHECKPOINT;
GO

-- So let's do one
BACKUP LOG DBMaint2008 TO
	DISK = 'C:\SQLskills\DBMaint2008_log.bck'
	WITH STATS;
GO

-- Note counters.....